HVDMreport: generates an HTML report using the input
Description
This method generates report using one of the HVDM outputs (either from the training(), screeening() or fitgene() commands.)
Usage
HVDMreport(HVDM,name)
Arguments
HVDM
a list output either by a training(), screening() or fitgene() command.
name
an optional argument allowing to specify the name of the HTML file (the .HTML extension is added automatically).
Value
Nothing is returned, but a message indicating the name of the HTML file and its location on the hard drive is given.
Details
If the output has been generated by training() or fitgene(), the HTML report contains
four sections:
1) Functions inputs.
2) Model score.
3) Fitted parameters.
4) Visual comparison of model and data.
In the fitgene() case comparisons with correponding results for genes in the training set are given.
If the output has been generated by the screening() command, the HTML report contains the following sections:
1) Inputs to the preceding training() command.
2) Inputs to the screening() command (such as bounds used to classify genes).
3) Results.
4) List of putative targets of the transcription factor under review.
The HTML report is genereated in the current working directory. Graphic files are stored in a subdirectory with a similar name.
References
M. Barenco, D. Tomescu, D. Brewer, R. Callard, J. Stark, M. Hubank (2006) Ranked predictions
of p53 targets using Hidden Variable Dynamic Modelling. Genome Biology, V7(3), R25.