estimerrors()), it will return a list of the supported rHVDM plattforms. All parameters of this function are optional, see below for details on the effect of omitting one or more of them. The method assumes the the amount of error is dependent both on the particular microarray and the signal intensity. For more details on how it is computed, please refer to the textual description of rHVDM.
estimerrors(eset,plattid,refchips,errtable)errtable argument. In future versions of rHVDM, if this argument and the errtable are missing, a search will be done among the supported plattforms to find a matching plattform, based on the individual genes identifiers. For now, omission of both arguments will be conductive to outputting a list of supported plattforms.
HVDMcheck,training,screening,fitgenedata(HVDMexample)
fiveGybis<-estimerrors(eset=fiveGyMAS5,plattid="affy_HGU133A",refchips=leastnoisychips)
#leastnoisy chips is a list of three chips identifiers stored in the HVDMexample data bundle
Run the code above in your browser using DataLab