fitgene(eset,gene,tHVDM,transforms,firstguess,criterion)This fitgene() step can only be applied after a training() step. The output to the training() step has to be fed through
the tHVDM argument.
The firstguess argument is optional (a first guess is generated internally by default).
However a first guess can be supplied by the user which can take several forms.
It can either be a vector with three entries containing a first guess for the basal rate,
the sensitivity, the degradation rate (in that order).
Alternatively, another output from the fitgene() function (for example from a gene that
has a similar expression profile) can be supplied as a firstguess argument.
The criterion argument is only used if the training object fed through the tHVDM command is a non-linear fit and determines the type of criterion used for model selection between Michelis-Menten and Hill. Possible values fed throught this argument are "BIC" (Bayesian information criterion, default) and "AIC" (Akaike information critertion). This argument is ignored in case of linear fitting.
training,screening,HVDMreportdata(HVDMexample)
tHVDMp53<-training(eset=fiveGyMAS5,genes=p53traingenes,degrate=0.8,actname="p53")
sHVDMcd38<-fitgene(eset=fiveGyMAS5,gene="205692_s_at",tHVDM=tHVDMp53)
Run the code above in your browser using DataLab