fitgene.lin(eset,gene,tHVDM,transforms,firstguess)transforms=c(). Even in this case the degradation rate will not be allowed to take non positive values as it causes problems with the
differential operator used internally. The value in the vector indicates the parameter to be transformed: "Bj": basal rate of transcription, "Sj": sensitivity, "Dj": degrdation rate.
The entry label indicates the transform to be applied; presently, only log-transforms are implemented (ie "exp").This fitgene() step can only be applied after a training() step. The output to the training() step has to be fed through
the tHVDM argument.
The firstguess argument is optional (a first guess is generated internally by default).
However a first guess can be supplied by the user which can take several forms.
It can either be a vector with three entries containing a first guess for the basal rate,
the sensitivity, the degradation rate (in that order).
Alternatively, another output from the fitgene() function (for example from a gene that
has a similar expression profile) can be supplied as a firstguess argument.
training,screening,HVDMreportdata(HVDMexample)
tHVDMp53<-training(eset=fiveGyMAS5,genes=p53traingenes,degrate=0.8,actname="p53")
sHVDMcd38<-fitgene.lin(eset=fiveGyMAS5,gene="205692_s_at",tHVDM=tHVDMp53)
Run the code above in your browser using DataLab