This screening step can only be applied if a training.nl() step has already been run.
The output to the training,nl() step can be given as the "HVDM" argument. A fit of each gene in the "genes" argument
is then performed and a model is selected according to the input to the criterion argument.Alternatively an output to a previously run screening() step can be supplied as an
"HVDM" argument. In this case, the fit is not performed once again. Feeding a previous output
of screening() to that same function again is useful only if the various bounds altered in the secon run.
In the case this option is used, the "eset" and "genes" arguments do not have to be supplied (they will
be ignored anyway).
The output of that function is a list containing the results. The relevant data frame is in the "results" member of the output.
Putative targets can be identified using the "class1" field of that data frame (see example).
Bounds determining whether a gene is a target of the transcription factor under review have to be supplied. They are:
- cl1zscorelow: lower bound for the Vj Z-score (default: 2.5)
- cl1modelscore: upper bound for the model score (default: 100.0).
This default will have to be changed in most cases. As a rule of thumb,
5x the model score for the genes in the training set can be used.
- cl1degraterange: lower and upper bounds for the degradation rate (default: c(0.01,5.0)). This is to
exclude those genes with an absurd degradation rate, measured in (unit time)\^(-1). In our example the
unit time is an hour. In the case the unit time is different, these default bounds will have to be altered accordingly.
An exponential transform is set by default for both the basal (Bj) and degradation (Dj) rates as well as the kinetic parameters (Vj and Kj) of the production function(through the transforms argument). This
forces the values for these parameters to be positive. It also helps to reach a better fit. To turn this off let transforms=c(). Even in this case the degradation rate will not be allowed to take non positive values as it causes problems with the
differential operator used internally. The value in the vector indicates the parameter to be transformed: "Bj": basal rate of transcription, "Dj": degradation rate.
The entry label indicates the transform to be applied; presently,
The argument criterion specifies which criterion should be used for model selection.