training(eset,genes,transforms,degrate,actname,pdata,forcetransforms)An exponential transform is set by default for both the basal (Bj) and degradation (Dj) rates (through the transforms argument). This
forces the values for both these parameters to be positive. It also helps to reach a better fit. To turn this off, set the forcetransforms
switch to FALSE. Even in this case the degradation rate will not be allowed to take non-positive values as it causes problems with the
differential operator used internally. The value in the vector indicates the parameter to be transformed: "Bj": basal rate of transcription, "Sj": sensitivity, "Dj": degrdation rate.
The entry label indicates the transform to be applied; presently, only log-tranforms are implemented (ie "exp").
The degrate argument is optional, but it is recommended to provide the algorithm with an externally measured degradation rate, as this
greatly improves the accuracy and robustness of the outcome.
The pdata argument is also optional. By default the method will use the phenoData contained in the expression set.
This argument can be used for excluding a time point, or an entire replicate. To extract the phenoData from the expression set,
use dataframe<-pData(eset). The dataframe object obtained can then be manipulated as desired.
The default name of the transcription factor is "trfact1".
HVDMcheck,screening,fitgene,HVDMreportdata(HVDMexample)
tHVDMp53<-training(eset=fiveGyMAS5,genes=p53traingenes,degrate=0.8,actname="p53")
Run the code above in your browser using DataLab